from setuptools import setup, find_packages

setup(
	name='zaider',
	version='0.0.2',
	description='Zaider Solutions & Technologies',
	packages=find_packages(),
	package_dir={'':'src'},

	author='Costin Leonte',
	author_email='costin.leonte@gmail.com',
	url='https://github.com/costin-leonte/zaider',

)